@@ -9,79 +9,192 @@
 
 #' Plots confidence intervals and point estimates
 #'
-#' This function plots the results of estimations (coefficients and confidence intervals). The function `iplot` restricts the output to variables created with [`i`], either interactions with factors or raw factors.
+#' This function plots the results of estimations (coefficients and confidence intervals). 
+#' The function `iplot` restricts the output to variables created with [`i`], either 
+#' interactions with factors or raw factors.
 #'
 #' @inheritParams etable
 #' @inheritSection etable Arguments keep, drop and order
 #'
-#' @param object Can be either: i) an estimation object (obtained for example from [`feols`], ii) a list of estimation objects (several results will be plotted at once), iii) a matrix of coefficients table, iv) a numeric vector of the point estimates -- the latter requiring the extra arguments `sd` or `ci_low` and `ci_high`.
+#' @param object Can be either: i) an estimation object (obtained for example from
+#'  [`feols`], ii) a list of estimation objects (several results will be plotted at
+#' once), iii) a matrix of coefficients table, iv) a numeric vector of the point 
+#' estimates -- the latter requiring the extra arguments `sd` or `ci_low` and `ci_high`.
 #' @param sd The standard errors of the estimates. It may be missing.
-#' @param ci_low If `sd` is not provided, the lower bound of the confidence interval. For each estimate.
-#' @param ci_high If `sd` is not provided, the upper bound of the confidence interval. For each estimate.
-#' @param horiz A logical scalar, default is `FALSE`. Whether to display the confidence intervals horizontally instead of vertically.
-#' @param x The value of the x-axis. If missing, the names of the argument `estimate` are used.
-#' @param x.shift Shifts the confidence intervals bars to the left or right, depending on the value of `x.shift`. Default is 0.
+#' @param ci_low If `sd` is not provided, the lower bound of the confidence interval. 
+#' For each estimate.
+#' @param ci_high If `sd` is not provided, the upper bound of the confidence interval. 
+#' For each estimate.
+#' @param horiz A logical scalar, default is `FALSE`. Whether to display the confidence 
+#' intervals horizontally instead of vertically.
+#' @param x The value of the x-axis. If missing, the names of the argument `estimate` 
+#' are used.
+#' @param x.shift Shifts the confidence intervals bars to the left or right, depending 
+#' on the value of `x.shift`. Default is 0.
 #' @param ci.width The width of the extremities of the confidence intervals. Default is `0.1`.
 #' @param ci_level Scalar between 0 and 1: the level of the CI. By default it is equal to 0.95.
-#' @param add Default is `FALSE`, if the intervals are to be added to an existing graph. Note that if it is the case, then the argument `x` MUST be numeric.
+#' @param add Default is `FALSE`, if the intervals are to be added to an existing 
+#' graph. Note that if it is the case, then the argument `x` MUST be numeric.
 #' @param pt.pch The patch of the coefficient estimates. Default is 1 (circle).
 #' @param cex Numeric, default is 1. Expansion factor for the points
 #' @param pt.cex The size of the coefficient estimates. Default is the other argument `cex`.
-#' @param col The color of the points and the confidence intervals. Default is 1 ("black"). Note that you can set the colors separately for each of them with `pt.col` and `ci.col`.
+#' @param col The color of the points and the confidence intervals. Default is 1 
+#' ("black"). Note that you can set the colors separately for each of them with `pt.col` and `ci.col`.
 #' @param pt.col The color of the coefficient estimates. Default is equal to the other argument `col`.
 #' @param ci.col The color of the confidence intervals. Default is equal to the other argument `col`.
 #' @param lwd General line with. Default is 1.
-#' @param pt.lwd The line width of the coefficient estimates. Default is equal to the other argument `lwd`.
-#' @param ci.lwd The line width of the confidence intervals. Default is equal to the other argument `lwd`.
+#' @param pt.lwd The line width of the coefficient estimates. Default is equal to 
+#' the other argument `lwd`.
+#' @param ci.lwd The line width of the confidence intervals. Default is equal to 
+#' the other argument `lwd`.
 #' @param ci.lty The line type of the confidence intervals. Default is 1.
-#' @param grid Logical, default is `TRUE`. Whether a grid should be displayed. You can set the display of the grid with the argument `grid.par`.
-#' @param grid.par List. Parameters of the grid. The default values are: `lty = 3` and `col = "gray"`. You can add any graphical parameter that will be passed to [`graphics::abline`]. You also have two additional arguments: use `horiz = FALSE` to disable the horizontal lines, and use `vert = FALSE` to disable the vertical lines. Eg: `grid.par = list(vert = FALSE, col = "red", lwd = 2)`.
-#' @param zero Logical, default is `TRUE`. Whether the 0-line should be emphasized. You can set the parameters of that line with the argument `zero.par`.
-#' @param zero.par List. Parameters of the zero-line. The default values are `col = "black"` and `lwd = 1`. You can add any graphical parameter that will be passed to [`graphics::abline`]. Example: `zero.par = list(col = "darkblue", lwd = 3)`.
-#' @param pt.join Logical, default is `FALSE`. If `TRUE`, then the coefficient estimates are joined with a line.
-#' @param pt.join.par List. Parameters of the line joining the coefficients. The default values are: `col = pt.col` and `lwd = lwd`. You can add any graphical parameter that will be passed to [`lines`]. Eg: `pt.join.par = list(lty = 2)`.
-#' @param ref Used to add points equal to 0 (typically to visualize reference points). Either: i) "auto" (default), ii) a character vector of length 1, iii) a list of length 1, iv) a named integer vector of length 1, or v) a numeric vector. By default, in `iplot`, if the argument `ref` has been used in the estimation, these references are automatically added. If ii), ie a character scalar, then that coefficient equal to zero is added as the first coefficient. If a list or a named integer vector of length 1, then the integer gives the position of the reference among the coefficients and the name gives the coefficient name. A non-named numeric value of `ref` only works if the x-axis is also numeric (which can happen in `iplot`).
-#' @param ref.line Logical or numeric, default is "auto", whose behavior depends on the situation. It is `TRUE` only if: i) interactions are plotted, ii) the x values are numeric and iii) a reference is found. If `TRUE`, then a vertical line is drawn at the level of the reference value. Otherwise, if numeric a vertical line will be drawn at that specific value.
-#' @param ref.line.par List. Parameters of the vertical line on the reference. The default values are: `col = "black"` and `lty = 2`. You can add any graphical parameter that will be passed to [`graphics::abline`]. Eg: `ref.line.par = list(lty = 1, lwd = 3)`.
-#' @param xlim.add A numeric vector of length 1 or 2. It represents an extension factor of xlim, in percentage. Eg: `xlim.add = c(0, 0.5)` extends `xlim` of 50% on the right. If of length 1, positive values represent the right, and negative values the left (Eg: `xlim.add = -0.5` is equivalent to `xlim.add = c(0.5, 0)`).
-#' @param ylim.add A numeric vector of length 1 or 2. It represents an extension factor of ylim, in percentage. Eg: `ylim.add = c(0, 0.5)` extends `ylim` of 50% on the top. If of length 1, positive values represent the top, and negative values the bottom (Eg: `ylim.add = -0.5` is equivalent to `ylim.add = c(0.5, 0)`).
-#' @param only.params Logical, default is `FALSE`. If `TRUE` no graphic is displayed, only the values of `x` and `y` used in the plot are returned.
-#' @param ... Other arguments to be passed to `summary`, if `object` is an estimation, and/or to the function `plot` or `lines` (if `add = TRUE`).
-#' @param sep The distance between two estimates -- only when argument `object` is a list of estimation results.
-#' @param as.multiple Logical: default is `FALSE`. Only when `object` is a single estimation result: whether each coefficient should have a different color, line type, etc. By default they all get the same style.
+#' @param grid Logical, default is `TRUE`. Whether a grid should be displayed. You 
+#' can set the display of the grid with the argument `grid.par`.
+#' @param grid.par List. Parameters of the grid. The default values are: `lty = 
+#' 3` and `col = "gray"`. You can add any graphical parameter that will be passed 
+#' to [`graphics::abline`]. You also have two additional arguments: use `horiz = 
+#' FALSE` to disable the horizontal lines, and use `vert = FALSE` to disable the 
+#' vertical lines. Eg: `grid.par = list(vert = FALSE, col = "red", lwd = 2)`.
+#' @param zero Logical, default is `TRUE`. Whether the 0-line should be emphasized. 
+#' You can set the parameters of that line with the argument `zero.par`.
+#' @param zero.par List. Parameters of the zero-line. The default values are 
+#' `col = "black"` and `lwd = 1`. You can add any graphical parameter that will be passed 
+#' to [`graphics::abline`]. Example: `zero.par = list(col = "darkblue", lwd = 3)`.
+#' @param pt.join Logical, default is `FALSE`. If `TRUE`, then the coefficient estimates 
+#' are joined with a line.
+#' @param df.t Integer scalar or `NULL` (default). The degrees of freedom (DoF) to use
+#' when computing the confidence intervals with the Student t. By default it 
+#' tries to capture the DoF from the estimation. To use a Normal law to compute the 
+#' confidence interval, use `df.t = Inf`.
+#' @param pt.join.par List. Parameters of the line joining the coefficients. The 
+#' default values are: `col = pt.col` and `lwd = lwd`. You can add any graphical 
+#' parameter that will be passed to [`lines`]. Eg: `pt.join.par = list(lty = 2)`.
+#' @param ref Used to add points equal to 0 (typically to visualize reference points). 
+#' Either: i) "auto" (default), ii) a character vector of length 1, iii) a list 
+#' of length 1, iv) a named integer vector of length 1, or v) a numeric vector. 
+#' By default, in `iplot`, if the argument `ref` has been used in the estimation, 
+#' these references are automatically added. If ii), ie a character scalar, then 
+#' that coefficient equal to zero is added as the first coefficient. If a list or 
+#' a named integer vector of length 1, then the integer gives the position of the 
+#' reference among the coefficients and the name gives the coefficient name. A non-named 
+#' numeric value of `ref` only works if the x-axis is also numeric (which can happen 
+#' in `iplot`).
+#' @param ref.line Logical or numeric, default is "auto", whose behavior depends 
+#' on the situation. It is `TRUE` only if: i) interactions are plotted, ii) the 
+#' x values are numeric and iii) a reference is found. If `TRUE`, then a vertical 
+#' line is drawn at the level of the reference value. Otherwise, if numeric a vertical 
+#' line will be drawn at that specific value.
+#' @param ref.line.par List. Parameters of the vertical line on the reference. The 
+#' default values are: `col = "black"` and `lty = 2`. You can add any graphical 
+#' parameter that will be passed to [`graphics::abline`]. Eg: `ref.line.par = list(lty = 1, lwd = 3)`.
+#' @param xlim.add A numeric vector of length 1 or 2. It represents an extension 
+#' factor of xlim, in percentage. Eg: `xlim.add = c(0, 0.5)` extends `xlim` of 50% 
+#' on the right. If of length 1, positive values represent the right, and negative 
+#' values the left (Eg: `xlim.add = -0.5` is equivalent to `xlim.add = c(0.5, 0)`).
+#' @param ylim.add A numeric vector of length 1 or 2. It represents an extension 
+#' factor of ylim, in percentage. Eg: `ylim.add = c(0, 0.5)` extends `ylim` of 50% 
+#' on the top. If of length 1, positive values represent the top, and negative values 
+#' the bottom (Eg: `ylim.add = -0.5` is equivalent to `ylim.add = c(0.5, 0)`).
+#' @param only.params Logical, default is `FALSE`. If `TRUE` no graphic is displayed, 
+#' only the values of `x` and `y` used in the plot are returned.
+#' @param ... Other arguments to be passed to `summary`, if `object` is an estimation, 
+#' and/or to the function `plot` or `lines` (if `add = TRUE`).
+#' @param sep The distance between two estimates -- only when argument `object` 
+#' is a list of estimation results.
+#' @param as.multiple Logical: default is `FALSE`. Only when `object` is a single 
+#' estimation result: whether each coefficient should have a different color, line 
+#' type, etc. By default they all get the same style.
 #' @param bg Background color for the plot. By default it is white.
-#' @param ci.join Logical default to `FALSE`. Whether to join the extremities of the confidence intervals. If `TRUE`, then you can set the graphical parameters with the argument `ci.join.par`.
-#' @param ci.join.par A list of parameters to be passed to [`graphics::lines`]. Only used if `ci.join=TRUE`. By default it is equal to `list(lwd = lwd, col = col, lty = 2)`.
-#' @param ci.fill Logical default to `FALSE`. Whether to fill the confidence intervals with a color. If `TRUE`, then you can set the graphical parameters with the argument `ci.fill.par`.
-#' @param ci.fill.par A list of parameters to be passed to [`graphics::polygon`]. Only used if `ci.fill=TRUE`. By default it is equal to `list(col = "lightgray", alpha = 0.5)`. Note that `alpha` is a special parameter that adds transparency to the color (ranges from 0 to 1).
-#' @param group A list, default is missing. Each element of the list reports the coefficients to be grouped while the name of the element is the group name. Each element of the list can be either: i) a character vector of length 1, ii) of length 2, or ii) a numeric vector. If equal to: i) then it is interpreted as a pattern: all element fitting the regular expression will be grouped (note that you can use the special character "^^" to clean the beginning of the names, see example), if ii) it corrsponds to the first and last elements to be grouped, if iii) it corresponds to the coefficients numbers to be grouped. If equal to a character vector, you can use a percentage to tell the algorithm to look at the coefficients before aliasing (e.g. `"%varname"`). Example of valid uses: `group=list(group_name=\"pattern\")`, `group=list(group_name=c(\"var_start\", \"var_end\"))`, `group=list(group_name=1:2))`. See details.
-#' @param group.par A list of parameters controlling the display of the group. The parameters controlling the line are: `lwd`, `tcl` (length of the tick), `line.adj` (adjustment of the position, default is 0), `tick` (whether to add the ticks), `lwd.ticks`, `col.ticks`. Then the parameters controlling the text: `text.adj` (adjustment of the position, default is 0), `text.cex`, `text.font`, `text.col`.
-#' @param pt.bg The background color of the point estimate (when the `pt.pch` is in 21 to 25). Defaults to NULL.
-#' @param lab.cex The size of the labels of the coefficients. Default is missing. It is automatically set by an internal algorithm which can go as low as `lab.min.cex` (another argument).
-#' @param lab.min.cex The minimum size of the coefficients labels, as set by the internal algorithm. Default is 0.85.
-#' @param lab.max.mar The maximum size the left margin can take when trying to fit the coefficient labels into it (only when `horiz = TRUE`). This is used in the internal algorithm fitting the coefficient labels. Default is `0.25`.
-#' @param lab.fit The method to fit the coefficient labels into the plotting region (only when `horiz = FALSE`). Can be `"auto"` (the default), `"simple"`, `"multi"` or `"tilted"`. If `"simple"`, then the classic axis is drawn. If `"multi"`, then the coefficient labels are fit horizontally across several lines, such that they don't collide. If `"tilted"`, then the labels are tilted. If `"auto"`, an automatic choice between the three is made.
-#' @param main The title of the plot. Default is `"Effect on __depvar__"`. You can use the special variable `__depvar__` to set the title (useful when you set the plot default with [`setFixest_coefplot`]).
-#' @param value.lab The label to appear on the side of the coefficient values. If `horiz = FALSE`, the label appears in the y-axis. If `horiz = TRUE`, then it appears on the x-axis. The default is equal to `"Estimate and __ci__ Conf. Int."`, with `__ci__` a special variable giving the value of the confidence interval.
-#' @param xlab The label of the x-axis, default is `NULL`. Note that if `horiz = TRUE`, it overrides the value of the argument `value.lab`.
-#' @param ylab The label of the y-axis, default is `NULL`. Note that if `horiz = FALSE`, it overrides the value of the argument `value.lab`.
+#' @param ci.join Logical default to `FALSE`. Whether to join the extremities of 
+#' the confidence intervals. If `TRUE`, then you can set the graphical parameters 
+#' with the argument `ci.join.par`.
+#' @param ci.join.par A list of parameters to be passed to [`graphics::lines`]. 
+#' Only used if `ci.join=TRUE`. By default it is equal to `list(lwd = lwd, col = col, lty = 2)`.
+#' @param ci.fill Logical default to `FALSE`. Whether to fill the confidence intervals 
+#' with a color. If `TRUE`, then you can set the graphical parameters with the argument `ci.fill.par`.
+#' @param ci.fill.par A list of parameters to be passed to [`graphics::polygon`]. 
+#' Only used if `ci.fill=TRUE`. By default it is equal to `list(col = "lightgray", alpha = 0.5)`. 
+#' Note that `alpha` is a special parameter that adds transparency to the color (ranges from 0 to 1).
+#' @param group A list, default is missing. Each element of the list reports the 
+#' coefficients to be grouped while the name of the element is the group name. Each 
+#' element of the list can be either: i) a character vector of length 1, ii) of 
+#' length 2, or ii) a numeric vector. If equal to: i) then it is interpreted as 
+#' a pattern: all element fitting the regular expression will be grouped (note that 
+#' you can use the special character "^^" to clean the beginning of the names, see 
+#' example), if ii) it corrsponds to the first and last elements to be grouped, 
+#' if iii) it corresponds to the coefficients numbers to be grouped. If equal to 
+#' a character vector, you can use a percentage to tell the algorithm to look at 
+#' the coefficients before aliasing (e.g. `"%varname"`). Example of valid uses: 
+#' `group=list(group_name=\"pattern\")`, `group=list(group_name=c(\"var_start\", \"var_end\"))`, 
+#' `group=list(group_name=1:2))`. See details.
+#' @param group.par A list of parameters controlling the display of the group. The 
+#' parameters controlling the line are: `lwd`, `tcl` (length of the tick), `line.adj` 
+#' (adjustment of the position, default is 0), `tick` (whether to add the ticks), 
+#' `lwd.ticks`, `col.ticks`. Then the parameters controlling the text: `text.adj` 
+#' (adjustment of the position, default is 0), `text.cex`, `text.font`, `text.col`.
+#' @param pt.bg The background color of the point estimate (when the `pt.pch` is 
+#' in 21 to 25). Defaults to NULL.
+#' @param lab.cex The size of the labels of the coefficients. Default is missing. 
+#' It is automatically set by an internal algorithm which can go as low as `lab.min.cex` 
+#' (another argument).
+#' @param lab.min.cex The minimum size of the coefficients labels, as set by the 
+#' internal algorithm. Default is 0.85.
+#' @param lab.max.mar The maximum size the left margin can take when trying to fit 
+#' the coefficient labels into it (only when `horiz = TRUE`). This is used in the 
+#' internal algorithm fitting the coefficient labels. Default is `0.25`.
+#' @param lab.fit The method to fit the coefficient labels into the plotting region 
+#' (only when `horiz = FALSE`). Can be `"auto"` (the default), `"simple"`, `"multi"` 
+#' or `"tilted"`. If `"simple"`, then the classic axis is drawn. If `"multi"`, then 
+#' the coefficient labels are fit horizontally across several lines, such that they 
+#' don't collide. If `"tilted"`, then the labels are tilted. If `"auto"`, an automatic 
+#' choice between the three is made.
+#' @param main The title of the plot. Default is `"Effect on __depvar__"`. You can 
+#' use the special variable `__depvar__` to set the title (useful when you set the 
+#' plot default with [`setFixest_coefplot`]).
+#' @param value.lab The label to appear on the side of the coefficient values. If 
+#' `horiz = FALSE`, the label appears in the y-axis. If `horiz = TRUE`, then it 
+#' appears on the x-axis. The default is equal to `"Estimate and __ci__ Conf. Int."`, 
+#' with `__ci__` a special variable giving the value of the confidence interval.
+#' @param xlab The label of the x-axis, default is `NULL`. Note that if `horiz = 
+#' TRUE`, it overrides the value of the argument `value.lab`.
+#' @param ylab The label of the y-axis, default is `NULL`. Note that if `horiz = 
+#' FALSE`, it overrides the value of the argument `value.lab`.
 #' @param sub A subtitle, default is `NULL`.
-#' @param style A character scalar giving the style of the plot to be used. You can set styles with the function [`setFixest_coefplot`], setting all the default values of the function. If missing, then it switches to either "default" or "iplot", depending on the calling function.
-#' @param i.select Integer scalar, default is 1. In `iplot`, used to select which variable created with `i()` to select. Only used when there are several variables created with [`i`]. This is an index, just try increasing numbers to hopefully obtain what you want. Note that it works much better when the variables are "pure" `i()` variables and not interacted with other variables. For example: `i(species, x1)` is good while `i(species):x1` isn't. The latter will also work but the index may feel weird in case there are many `i()` variables.
+#' @param style A character scalar giving the style of the plot to be used. You 
+#' can set styles with the function [`setFixest_coefplot`], setting all the default 
+#' values of the function. If missing, then it switches to either "default" or "iplot", 
+#' depending on the calling function.
+#' @param i.select Integer scalar, default is 1. In `iplot`, used to select which 
+#' variable created with `i()` to select. Only used when there are several variables 
+#' created with [`i`]. This is an index, just try increasing numbers to hopefully 
+#' obtain what you want. Note that it works much better when the variables are "pure" 
+#' `i()` variables and not interacted with other variables. For example: `i(species, x1)` 
+#' is good while `i(species):x1` isn't. The latter will also work but the index 
+#' may feel weird in case there are many `i()` variables.
 #'
 #' @seealso
-#' See [`setFixest_coefplot`] to set the default values of `coefplot`, and the estimation functions: e.g. [`feols`], [`fepois`][fixest::feglm], [`feglm`], [`fenegbin`][fixest::femlm].
+#' See [`setFixest_coefplot`] to set the default values of `coefplot`, and the estimation 
+#' functions: e.g. [`feols`], [`fepois`][fixest::feglm], [`feglm`], [`fenegbin`][fixest::femlm].
 #'
 #' @section Setting custom default values:
-#' The function `coefplot` dispose of many arguments to parametrize the plots. Most of these arguments can be set once an for all using the function [`setFixest_coefplot`]. See Example 3 below for a demonstration.
+#' The function `coefplot` dispose of many arguments to parametrize the plots. Most 
+#' of these arguments can be set once an for all using the function [`setFixest_coefplot`]. 
+#' See Example 3 below for a demonstration.
 #'
 #' @section iplot:
 #'
-#' The function `iplot` restricts `coefplot` to interactions or factors created with the function [`i`]. Only *one* of the i-variables will be plotted at a time. If you have several i-variables, you can navigate through them with the `i.select` argument.
+#' The function `iplot` restricts `coefplot` to interactions or factors created 
+#' with the function [`i`]. Only *one* of the i-variables will be plotted at a time. 
+#' If you have several i-variables, you can navigate through them with the `i.select` argument.
 #'
-#' The argument `i.select` is an index that will go through all the i-variables. It will work well if the variables are pure, meaning not interacted with other variables. If the i-variables are interacted, the index may have an odd behavior but will (in most cases) work all the same, just try some numbers up until you (hopefully) obtain the graph you want.
+#' The argument `i.select` is an index that will go through all the i-variables. 
+#' It will work well if the variables are pure, meaning not interacted with other 
+#' variables. If the i-variables are interacted, the index may have an odd behavior 
+#' but will (in most cases) work all the same, just try some numbers up until you 
+#' (hopefully) obtain the graph you want.
 #'
-#' Note, importantly, that interactions of two factor variables are (in general) disregarded since they would require a 3-D plot to be properly represented.
+#' Note, importantly, that interactions of two factor variables are (in general) 
+#' disregarded since they would require a 3-D plot to be properly represented.
 #'
 #'
 #' @author
@@ -234,7 +347,8 @@
 #' coefplot(est, group = list(Sepal = "^^Sepal.", Species = "^^Species"))
 #'
 #'
-coefplot = function(object, ..., style = NULL, sd, ci_low, ci_high, x, x.shift = 0, horiz = FALSE,
+coefplot = function(object, ..., style = NULL, sd, ci_low, ci_high, df.t = NULL, 
+                    x, x.shift = 0, horiz = FALSE,
                     dict = getFixest_dict(), keep, drop, order, ci.width = "1%",
                     ci_level = 0.95, add = FALSE, pt.pch = c(20, 17, 15, 21, 24, 22), pt.bg = NULL, cex = 1,
                     pt.cex = cex, col = 1:8, pt.col = col, ci.col = col, lwd = 1, pt.lwd = lwd,
@@ -351,8 +465,8 @@ coefplot = function(object, ..., style = NULL, sd, ci_low, ci_high, x, x.shift =
 
     info = coefplot_prms(object = object, ..., sd = sd, ci_low = ci_low, ci_high = ci_high,
                          x = x, x.shift = x.shift, dict = dict, keep = keep, drop = drop,
-                         order = order, ci_level = ci_level, ref = ref, only.i = is_iplot,
-                         sep = sep, as.multiple = as.multiple)
+                         order = order, ci_level = ci_level, df.t = df.t, ref = ref, 
+                         only.i = is_iplot, sep = sep, as.multiple = as.multiple)
 
     prms = info$prms
     AXIS_AS_NUM = info$num_axis
@@ -1445,7 +1559,7 @@ coefplot = function(object, ..., style = NULL, sd, ci_low, ci_high, x, x.shift =
 
 
 coefplot_prms = function(object, ..., sd, ci_low, ci_high, x, x.shift = 0, dict,
-                         keep, drop, order, ci_level = 0.95, ref = "auto",
+                         keep, drop, order, ci_level = 0.95, df.t = NULL, ref = "auto",
                          only.i = TRUE, sep, as.multiple = FALSE){
 
     # get the default for:
@@ -1641,6 +1755,7 @@ coefplot_prms = function(object, ..., sd, ci_low, ci_high, x, x.shift = 0, dict,
             } else {
                 stop("Argument 'object' is a matrix but it should contain 4 columns (the two first ones should be reporting the estimate and the standard-error). Either provide an appropriate matrix or give directly the vector of estimated coefficients in arg. estimate.")
             }
+            
         } else if(length(object[1]) > 1 || !is.null(dim(object)) || !is.numeric(object)){
             stop("Argument 'object' must be either: i) an estimation object, ii) a matrix of coefficients table, or iii) a numeric vector of the point estimates. Currently it is neither of the three.")
         } else {
@@ -1658,7 +1773,39 @@ coefplot_prms = function(object, ..., sd, ci_low, ci_high, x, x.shift = 0, dict,
             if(!missing(ci_low) || !missing(ci_high)) warning("Since 'sd' is provided, arguments 'ci_low' or 'ci_high' are ignored.")
 
             # We compute the CI
-            nb = abs(qnorm((1 - ci_level)/2))
+            check_arg(df.t, "NULL | numeric scalar GE{1}")
+            if(inherits(object, "fixest")){
+                if(is.null(df.t)){
+                    df.t = degrees_freedom(object, "t")
+                    if(is.null(df.t)){
+                        # may for user defined functions using fixest
+                        df.t = degrees_freedom(object, "resid")
+                        if(is.null(df.t)){
+                            # let's be safe
+                            df.t = Inf
+                        }
+                    }
+                }
+                
+                nb = fixest_CI_factor(object, ci_level, df.t = df.t)[2]
+            } else {
+                # non fixest objects
+                if(is.null(df.t)){
+                    df.t = tryCatch(nobs(object) - length(coef(object)), 
+                                    error = function(e) NULL)
+                    if(is.null(df.t)){
+                        if(not_too_many_messages("coefplot_df")){
+                            message("The degrees of freedom for the t distribution could",
+                                    " not be deduced. Using a Normal distribution instead.\n",
+                                    "Note that you can provide the argument `df.t` directly.")
+                        }
+                        df.t = Inf
+                    }
+                }
+                
+                nb = abs( qt( (1-ci_level) / 2, df.t) )
+            }
+            
             ci_high = estimate + nb*sd
             ci_low = estimate - nb*sd
         }
