@@ -997,15 +997,17 @@ std::string cpp_add_commas(double x, int r = 1, bool whole = true){
     // for whole numbers => no trailing digits
     // does not accept vectors, although super easy to expand to vectors
 
-    std::string x_str = std::to_string(static_cast<int>(abs(x)));
+    double xr = round(x * pow(10, r)) / pow(10, r);
+
+    std::string x_str = std::to_string(static_cast<int>(abs(xr)));
     std::string res;
 
-    if(x < 0){
+    if(xr < 0){
         res.push_back('-');
-        x = -x;
+        xr = -xr;
     }
 
-    if(x < 1000){
+    if(xr < 1000){
         res.insert(res.size(), x_str);
 
     } else {
@@ -1021,23 +1023,18 @@ std::string cpp_add_commas(double x, int r = 1, bool whole = true){
         }
     }
 
-    double rest = x - floor(x);
-    if((rest != 0 || !whole) && r > 0){
+    double rest = xr - floor(xr);
+    bool is_whole = whole && (x - floor(x)) == 0;
+    if(!is_whole && r > 0){
         // not a whole number
 
         res.push_back('.');
 
-        if(r == 1){
-            res.push_back(std::to_string(static_cast<int>(round(rest * 10)))[0]);
+        std::string rest_str = std::to_string(rest);
+        int nr = rest_str.size();
 
-        } else {
-            double rounded_rest = round(rest * pow(10, r)) / pow(10, r);
-            std::string rest_str = std::to_string(rounded_rest);
-            int nr = rest_str.size();
-
-            for(int i=2 ; i < nr && i-1 <= r ; ++i){
-                res.push_back(rest_str[i]);
-            }
+        for(int i=2 ; i < nr && i-1 <= r ; ++i){
+            res.push_back(rest_str[i]);
         }
     }
 
@@ -1308,8 +1305,171 @@ double cpp_hash_string(std::string x){
     return res;
 }
 
+inline bool is_md_markup(const char * x, int i, int n){
+    if(x[i] != '*') return false;
 
+    if(i + 1 >= n || x[i + 1] != '*') return true;
+    if(i + 2 >= n ||  x[i + 2] != '*') return true;
+    if(i + 3 < n && x[i + 3] == '*') return false;
+    return true;
+}
 
+inline bool is_special_char(const char x){
+    return x == '&' || x == '%' || x == '_' || x == '^' || x == '#';
+}
+
+inline int find_id_markup(const char * x, int i, int n){
+    if(i + 1 >= n || x[i + 1] != '*') return 1;
+    if(i + 2 >= n ||  x[i + 2] != '*') return 2;
+    return 3;
+}
+
+std::string apply_escape_markup(const char * x){
+    //
+    //
+    //
+    // element 0 is the main character vector: it is never closed
+
+    int n = std::strlen(x);
+    std::vector<std::string> tmp_all(4, "");
+    std::string tmp = "", res = "";
+
+    std::vector<bool> is_open(4, false);
+    std::vector<int> id_open;
+    id_open.push_back(0);
+
+    std::vector<std::string> open_tags{"", "\\textit{", "\\textbf{", "\\textbf{\\textit{"};
+    std::vector<std::string> closing_tags{"", "}", "}", "}}"};
+    std::vector<std::string> stars{"", "*", "**", "***"};
+
+    int id_mkp = 0;
+
+    int i = 0, i_save = 0;
+    while(i < n){
+        if(x[i] == '$'){
+            if(i > 0 && x[i - 1] == '\\'){
+                tmp_all[id_mkp] += '$';
+            } else {
+                // This is an equation
+                i_save = i;
+                ++i;
+                tmp = "$";
+                while(i < n && (x[i] != '$' || x[i - 1] == '\\')){
+                    tmp += x[i];
+                    ++i;
+                }
+
+                if(i == n){
+                    // we went all the way without a closing $
+                    // => we come back, escape it and continue
+                    tmp_all[id_mkp] += "\\$";
+                    i = i_save;
+
+                } else {
+                    tmp_all[id_mkp] += tmp + "$";
+                }
+            }
+        } else if(is_special_char(x[i])){
+            if(i > 0 && x[i - 1] == '\\'){
+                // we do nothing
+                tmp_all[id_mkp] += x[i];
+            } else {
+                // we escape
+                tmp_all[id_mkp] += "\\";
+                tmp_all[id_mkp] += x[i];
+            }
+
+        } else if(x[i] == '\\'){
+            if(i + 1 < n && x[i + 1] == '*'){
+                // escape of MD markup
+                ++i;
+                while(i < n && x[i] == '*'){
+                    tmp_all[id_mkp] += '*';
+                    ++i;
+                }
+                --i; // compensated at the end of the main while
+            } else {
+                tmp_all[id_mkp] += '\\';
+            }
+        } else if(is_md_markup(x, i, n)){
+            id_mkp = find_id_markup(x, i, n);
+            i += id_mkp - 1;
+
+            if(is_open[id_mkp]){
+
+                for(int j=id_open.size() - 1 ; j >= 1 ; --j){
+
+                    int id_j = id_open[j];
+                    int id_prev = id_open[j - 1];
+
+                    if(id_j == id_mkp){
+                        // we apply the markup
+                        tmp = open_tags[id_mkp] + tmp_all[id_mkp] + closing_tags[id_mkp];
+
+                        tmp_all[id_prev] += tmp;
+
+                        is_open[id_mkp] = false;
+                        id_open.pop_back();
+                        tmp_all[id_mkp] = "";
+                        id_mkp = id_prev;
+                        break;
+
+                    } else {
+                        // we flush: the markup is invalid
+                        // example:  "** bonjour * les gens **"
+
+                        tmp = stars[id_j] + tmp_all[id_j];
+                        tmp_all[id_j] = "";
+                        tmp_all[id_prev] += tmp;
+
+                        is_open[id_j] = false;
+                        id_open.pop_back();
+                    }
+                }
+
+            } else {
+                is_open[id_mkp] = true;
+                id_open.push_back(id_mkp);
+            }
+
+        } else {
+            tmp_all[id_mkp] += x[i];
+        }
+        ++i;
+    }
+
+    // we flush the rest if needed
+    for(int j=id_open.size() - 1 ; j >= 1 ; --j){
+        int id_j = id_open[j];
+        int id_prev = id_open[j - 1];
+
+        tmp = stars[id_j] + tmp_all[id_j];
+        tmp_all[id_j] = "";
+        tmp_all[id_prev] += tmp;
+    }
+
+    return tmp_all[0];
+}
+
+
+// [[Rcpp::export]]
+StringVector cpp_escape_markup(SEXP Rstr){
+    // cpp_escape_markup("**bonjour** *les* ***gens * \\***heureux*** ")
+    // cpp_escape_markup("stars: 10%: *, 5%: **, 1%: ***")
+
+    int n = LENGTH(Rstr);
+    StringVector res(n);
+
+    if(n == 0){
+        return res;
+    }
+
+    for(int i=0 ; i<n ; ++i){
+        res[i] = apply_escape_markup(CHAR(STRING_ELT(Rstr, i)));
+    }
+
+    return res;
+}
 
 
 
